@@ -16,6 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <glib.h>
 #include <gtk/gtk.h>
 #include "main.h"
 #include "utils.h"
@@ -29,7 +30,7 @@ read_history ()
 {
   /* Build file path */
   gchar* history_path = g_build_filename(g_get_home_dir(),
-                                         HISTFILE,
+                                         HISTORY_FILE,
                                          NULL);
   /* Open the file for reading */
   FILE* history_file = fopen(history_path, "rb");
@@ -66,7 +67,7 @@ save_history()
   check_dirs();
   /* Build file path */
   gchar* history_path = g_build_filename(g_get_home_dir(),
-                                         HISTFILE,
+                                         HISTORY_FILE,
                                          NULL);
   /* Open the file for writing */
   FILE* history_file = fopen(history_path, "wb");
@@ -102,7 +103,7 @@ append_item(gchar* item)
     /* Prepend new item */
     history = g_slist_prepend(history, g_strdup(item));
     /* Shorten history if necessary */
-    GSList* last_possible_element = g_slist_nth(history, prefs.histlim - 1);
+    GSList* last_possible_element = g_slist_nth(history, prefs.history_limit - 1);
     if (last_possible_element)
     {
       /* Free last posible element and subsequent elements */
@@ -110,7 +111,7 @@ append_item(gchar* item)
       last_possible_element->next = NULL;
     }
     /* Save changes */
-    if (prefs.savehist)
+    if (prefs.save_history)
       save_history();
   }
 }
@@ -122,7 +123,7 @@ truncate_history()
   if (history)
   {
     /* Shorten history if necessary */
-    GSList* last_possible_element = g_slist_nth(history, prefs.histlim - 1);
+    GSList* last_possible_element = g_slist_nth(history, prefs.history_limit - 1);
     if (last_possible_element)
     {
       /* Free last posible element and subsequent elements */
@@ -130,7 +131,7 @@ truncate_history()
       last_possible_element->next = NULL;
     }
     /* Save changes */
-    if (prefs.savehist)
+    if (prefs.save_history)
       save_history();
   }
 }
