@@ -16,17 +16,20 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <glib.h>
 #include <gtk/gtk.h>
 #include "main.h"
 #include "utils.h"
+#include "daemon.h"
+#include "history.h"
 #include "parcellite-i18n.h"
 
 /* Creates program related directories if needed */
 void
 check_dirs()
 {
-  gchar* data_dir = g_build_path("/", g_get_home_dir(), PARCDATADIR,  NULL);
-  gchar* config_dir = g_build_path("/", g_get_home_dir(), PARCCONFIGDIR,  NULL);
+  gchar* data_dir = g_build_path("/", g_get_home_dir(), DATA_DIR,  NULL);
+  gchar* config_dir = g_build_path("/", g_get_home_dir(), CONFIG_DIR,  NULL);
   /* Check if data directory exists */
   if (!g_file_test(data_dir, G_FILE_TEST_EXISTS))
   {
@@ -61,7 +64,6 @@ is_hyperlink(gchar* text)
   return result;
 }
 
-
 /* Parses the program arguments. Returns TRUE if program needs
  * to exit after parsing is complete
  */
@@ -110,7 +112,7 @@ parse_options(int argc, char* argv[])
                                "  echo \"copied to clipboard\" | parcellite -o"));
   /* Set description */
   g_option_context_set_description(context,
-                                 _("Written by Xyhthyx.\n"
+                                 _("Written by Gilberto \"Xyhthyx\" Miralla.\n"
                                    "Report bugs to <xyhthyx@gmail.com>."));
   /* Add entries and parse options */
   g_option_context_add_main_entries(context, main_entries, NULL);
@@ -122,18 +124,12 @@ parse_options(int argc, char* argv[])
   /* Do not display icon option */
   if (icon)
   {
-    prefs.noicon = TRUE;
+    prefs.no_icon = TRUE;
   }
   /* Run as daemon option */
   else if (daemon)
   {
-    /* Daemon mode basically just creates clipboard and primary objects
-     * and keeps them alive until the program is killed
-     */
-    GtkClipboard* cb = gtk_clipboard_get(GDK_SELECTION_CLIPBOARD);
-    GtkClipboard* prim = gtk_clipboard_get(GDK_SELECTION_PRIMARY);
-    gtk_main();
-    /* Result true so program exits when finished parsing */
+    init_daemon_mode();
     result = TRUE;
   }
   /* Print clipboard option */
